Editor de letras en línea
=========================



El editor de letras en línea reside en `http://mark.e37.mx/editor/ <http://mark.e37.mx/editor/>`_, y cuenta con los siguientes convertidores:

:HTML: Convertidor predeterminado, con coloreado y estilo por sección de la letra.

:IM: Formato para compartir letra a través de servicios de mensajería instantánea, como WhatsApp y Messenger.

:MD: Formato Markdown, como subconjunto limitado de la letra, limitado a negritas, itálicas, y negritas con itálicas (el origen de Marke37, antes de tener que meter más secciones).